@@ -1,8 +1,10 @@
-from insights.parsers.teamdctl_config_dump import TeamdctlConfigDump
-from insights.parsers import teamdctl_config_dump
-from insights.tests import context_wrap
 import doctest
 
+from insights.parsers import teamdctl_config_dump
+from insights.parsers.teamdctl_config_dump import TeamdctlConfigDump
+from insights.parsers.tests import test_empty_skip
+from insights.tests import context_wrap
+
 TEAMDCTL_CONFIG_DUMP_INFO = """
 {
     "device": "team0",
@@ -38,6 +40,10 @@ def test_teamdctl_state_dump():
     assert result.runner_hwaddr_policy == 'only_active'
 
 
+def test_teamdctl_state_dump_empty():
+    assert 'Empty output.' in test_empty_skip(TeamdctlConfigDump)
+
+
 def test_nmcli_doc_examples():
     env = {
             'teamdctl_config_dump': TeamdctlConfigDump(context_wrap(TEAMDCTL_CONFIG_DUMP_INFO)),
