@@ -18,6 +18,7 @@ class Specs(SpecSet):
     aws_instance_id_pkcs7 = RegistryPoint()
     aws_instance_type = RegistryPoint()
     awx_manage_check_license = RegistryPoint()
+    awx_manage_check_license_data = RegistryPoint(filterable=True)
     azure_instance_type = RegistryPoint()
     azure_instance_plan = RegistryPoint()
     bios_uuid = RegistryPoint()
@@ -204,6 +205,7 @@ class Specs(SpecSet):
     hammer_task_list = RegistryPoint()
     satellite_enabled_features = RegistryPoint()
     haproxy_cfg = RegistryPoint()
+    haproxy_cfg_scl = RegistryPoint()
     heat_api_log = RegistryPoint(filterable=True)
     heat_conf = RegistryPoint()
     heat_crontab = RegistryPoint()
@@ -631,6 +633,7 @@ class Specs(SpecSet):
     sysctl_conf_initramfs = RegistryPoint(multi_output=True)
     sysctl_conf = RegistryPoint()
     sysctl = RegistryPoint()
+    systemctl_cat_dnsmasq_service = RegistryPoint()
     systemctl_cat_rpcbind_socket = RegistryPoint()
     systemctl_cinder_volume = RegistryPoint()
     systemctl_httpd = RegistryPoint()
